
local FOLDER_NAME, SSA = ...

local L = LibStub("AceLocale-3.0"):GetLocale("ShamanAuras", true)
local Auras = LibStub("AceAddon-3.0"):GetAddon("ShamanAuras")
local AceGUI = LibStub("AceGUI-3.0");

local lgIcon,lgGlow,smIcon,smGlow = 32,45,25,35;
local x,y = 0,0,0;
local bg,low,med,high = "BACKGROUND","LOW","MEDIUM","HIGH"

-- Aura Group Builder
local function CreateGroup(name,parent)
	SSA[name] = CreateFrame("Frame",name,parent);
	local Group = SSA[name];
	Group:SetFrameStrata(bg);
	Group:Show();
	
	return Group;
end

-- Aura Icon Builder
local function InitializeFrames(name,parent,icon,iconSize,glowSize,charge)
	
	SSA[name] = CreateFrame("Frame",name,parent);
	local Frame = SSA[name];
	Frame:SetFrameStrata("LOW");
	Frame:SetWidth(iconSize);
	Frame:SetHeight(iconSize);
	Frame:Show();

	Frame.texture = Frame:CreateTexture(nil,"BACKGROUND");
	Frame.texture:SetTexture("Interface\\addons\\ShamanAuras\\media\\ICONS\\"..icon);
	Frame.texture:SetAllPoints(Frame);
	
	Frame.CD = CreateFrame("Cooldown", name.."CD", Frame, "CooldownFrameTemplate");
	Frame.CD:SetAllPoints(Frame);
	
	Frame.CD.text = Frame.CD:CreateFontString(nil, "MEDIUM", "GameFontHighlightLarge");
	Frame.CD.text:SetAllPoints(Frame.CD);
	Frame.CD.text:SetPoint("CENTER",0,0);
	Frame.CD.text:SetTextColor(1,1,0,1);
	
	if (glowSize) then
		--[[SSA[name.."Glow"] = CreateFrame("Frame",name.."Glow",parent);
		local Glow = SSA[name.."Glow"];
		Glow:SetFrameStrata("BACKGROUND");
		Glow:SetWidth(glowSize);
		Glow:SetHeight(glowSize);]]
		Frame.glow = CreateFrame("Frame",name.."Glow",Frame);
		Frame.glow:SetPoint("CENTER",0,0);
		Frame.glow:SetFrameStrata("BACKGROUND");
		Frame.glow:SetWidth(glowSize);
		Frame.glow:SetHeight(glowSize);
		Frame.glow:Show();
	end
	if (charge) then
		Frame.ChargeCD = CreateFrame("Cooldown", name.."ChargeCD", Frame, "CooldownFrameTemplate");
		Frame.ChargeCD:SetAllPoints(Frame);
		Frame.ChargeCD:SetFrameStrata("LOW");
		Frame.ChargeCD:Show()

		Frame.Charges = CreateFrame("Frame",name.."Charges",Frame);
		Frame.Charges:SetAllPoints(Frame);
		Frame.Charges:SetFrameStrata(med);
		Frame.Charges:SetWidth(iconSize);
		Frame.Charges:SetHeight(iconSize);

		Frame.Charges.text = Frame.Charges:CreateFontString(nil, "MEDIUM", "GameFontHighlightLarge");
		Frame.Charges.text:SetPoint("BOTTOMRIGHT",-3,3);
		Frame.Charges.text:SetFont("Interface\\addons\\ShamanAuras\\Media\\fonts\\ABF.ttf", 13.5,"OUTLINE");
		Frame.Charges.text:SetTextColor(1,1,1,1);		
	end
	_G["SSA_"..name] = Frame;
end

-----------------------------------------------------------------------
-- Restoration Frames
-----------------------------------------------------------------------
local AuraGroup,LargeIconGrpTop,LargeIconGrpBot,SmallIconGrpLeft,SmallIconGrpRight

-- Build Restoration Aura Group Containers
AuraGroup = CreateGroup("AuraGroupRes",UIParent);
LargeIconGrpTop = CreateGroup("LargeIconGrpTopRes",AuraGroup);
LargeIconGrpBot = CreateGroup("LargeIconGrpBotRes",AuraGroup);
SmallIconGrpLeft = CreateGroup("SmallIconGrpLeftRes",AuraGroup);
SmallIconGrpRight = CreateGroup("SmallIconGrpRightRes",AuraGroup);

-- Build Large Restoration Icon Frames
InitializeFrames("AscendanceRes",LargeIconGrpBot,"shared\\ascendance",lgIcon);
InitializeFrames("CloudburstTotem",LargeIconGrpTop,"totems\\cloudburst_totem",lgIcon);
InitializeFrames("GiftOfQueen",LargeIconGrpBot,"restoration\\gift_of_the_queen",lgIcon);
InitializeFrames("HealingRain",LargeIconGrpTop,"shared\\healing_rain",lgIcon);
InitializeFrames("HealingStreamTotem",LargeIconGrpTop,"totems\\healing_stream_totem",lgIcon,nil,true);
InitializeFrames("HealingTideTotem",LargeIconGrpBot,"totems\\healing_tide_totem",lgIcon);
InitializeFrames("Riptide",LargeIconGrpTop,"restoration\\riptide",lgIcon,nil,true);
InitializeFrames("SpiritLinkTotem",LargeIconGrpBot,"totems\\spirit_link_totem",lgIcon);
InitializeFrames("UnleashLife",LargeIconGrpTop,"restoration\\unleash_life",lgIcon);
InitializeFrames("Wellspring",LargeIconGrpBot,"restoration\\wellspring",lgIcon);
InitializeFrames("WindRushTotemRes",LargeIconGrpBot,"totems\\wind_rush_totem",lgIcon);

-- Build Small Restoration Icon Frames
InitializeFrames("AncestralGuidanceRes",SmallIconGrpRight,"shared\\ancestral_guidance",smIcon);
InitializeFrames("AstralShiftRes",SmallIconGrpRight,"shared\\astral_shift",smIcon);
InitializeFrames("EarthenShieldTotem",SmallIconGrpLeft,"totems\\earthen_shield_totem",smIcon);
InitializeFrames("EarthgrabTotemRes",SmallIconGrpRight,"totems\\earthgrab_totem",smIcon);
InitializeFrames("FlameShockRes",SmallIconGrpRight,"shared\\flame_shock",smIcon,smGlow);
InitializeFrames("GustWindRes",SmallIconGrpRight,"shared\\gust_of_wind",smIcon);
InitializeFrames("HexRes",SmallIconGrpLeft,"shared\\hex",smIcon);
InitializeFrames("LavaBurstRes",SmallIconGrpRight,"elemental\\lava_burst",smIcon,smGlow,true);
InitializeFrames("LightningSurgeTotemRes",SmallIconGrpRight,"totems\\lightning_surge_totem",smIcon);
InitializeFrames("PurifySpirit",SmallIconGrpLeft,"restoration\\purify_spirit",smIcon);
InitializeFrames("SpiritwalkersGrace",SmallIconGrpLeft,"restoration\\spiritwalkers_grace",smIcon);
InitializeFrames("VoodooTotemRes",SmallIconGrpLeft,"totems\\voodoo_totem",smIcon);
InitializeFrames("WindShearRes",SmallIconGrpLeft,"shared\\wind_shear",smIcon);

-------------------------------------------------------------------------------------------------------
----- Build and Initialize Status Bars
-------------------------------------------------------------------------------------------------------

-- Build Tidal Waves Status Bar
SSA.TidalWavesBar = CreateFrame("StatusBar","TidalWavesBar",AuraGroup);
local TidalWavesBar = SSA.TidalWavesBar;
TidalWavesBar:SetStatusBarTexture("Interface\\addons\\ShamanAuras\\media\\statusbar\\halvess");
TidalWavesBar:GetStatusBarTexture():SetHorizTile(false);
TidalWavesBar:GetStatusBarTexture():SetVertTile(false);
TidalWavesBar:SetPoint("CENTER",AuraGroup,"CENTER",0,-202);
--TidalWavesBar:SetWidth(225);
--TidalWavesBar:SetHeight(7);
TidalWavesBar:SetFrameStrata("LOW");
TidalWavesBar:SetStatusBarColor(0.35,0.76,1);
TidalWavesBar:Hide();

TidalWavesBar.bg = TidalWavesBar:CreateTexture(nil,"BACKGROUND");
TidalWavesBar.bg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar");
TidalWavesBar.bg:SetAllPoints(true);
TidalWavesBar.bg:SetVertexColor(0,0,0);
TidalWavesBar.bg:SetAlpha(0.65);

-- Animation for Tidal Waves Status Bar
TidalWavesBar.Flash = TidalWavesBar:CreateAnimationGroup();
TidalWavesBar.Flash:SetLooping("BOUNCE");

TidalWavesBar.Flash.fadeIn = TidalWavesBar.Flash:CreateAnimation("Alpha");
TidalWavesBar.Flash.fadeIn:SetFromAlpha(1);
TidalWavesBar.Flash.fadeIn:SetToAlpha(0.25);
TidalWavesBar.Flash.fadeIn:SetDuration(0.33);

TidalWavesBar.Flash.fadeOut = TidalWavesBar.Flash:CreateAnimation("Alpha");
TidalWavesBar.Flash.fadeOut:SetFromAlpha(0.25);
TidalWavesBar.Flash.fadeOut:SetToAlpha(1);
TidalWavesBar.Flash.fadeOut:SetDuration(0.33);
TidalWavesBar.Flash.fadeOut:SetEndDelay(0);

-- Build Cloudburst Totem Status Bar
--[[SSA.CloudburstAbsorbBar = CreateFrame("StatusBar","CloudburstAbsorbBar",AuraGroup);
local CloudburstAbsorbBar = SSA.CloudburstAbsorbBar;
CloudburstAbsorbBar:SetStatusBarTexture("Interface\\addons\\ShamanAuras\\media\\statusbar\\fifths");
CloudburstAbsorbBar:GetStatusBarTexture():SetHorizTile(false);
CloudburstAbsorbBar:GetStatusBarTexture():SetVertTile(false);
CloudburstAbsorbBar:SetPoint("CENTER",AuraGroup,"CENTER",0,-139);
CloudburstAbsorbBar:SetWidth(260);
CloudburstAbsorbBar:SetHeight(18);
CloudburstAbsorbBar:SetFrameStrata("LOW");
CloudburstAbsorbBar:SetStatusBarColor(0,0.5,1);
CloudburstAbsorbBar:Hide();

CloudburstAbsorbBar.bg = CloudburstAbsorbBar:CreateTexture(nil,"BACKGROUND");
CloudburstAbsorbBar.bg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar");
CloudburstAbsorbBar.bg:SetAllPoints(true);
CloudburstAbsorbBar.bg:SetVertexColor(0,0,0);
CloudburstAbsorbBar.bg:SetAlpha(0.5);

CloudburstAbsorbBar.text = CloudburstAbsorbBar:CreateFontString(nil, "HIGH", "GameFontHighlightLarge");
CloudburstAbsorbBar.text:SetPoint("CENTER",CloudburstAbsorbBar,"RIGHT",-25,0);
CloudburstAbsorbBar.text:SetFont("Interface\\addons\\ShamanAuras\\Media\\fonts\\Continuum_Medium.ttf", 12);
CloudburstAbsorbBar.text:SetTextColor(1,1,1,1);

-- Build Cloudburst Timer Status Bar
CloudburstAbsorbBar.Timer = CreateFrame("StatusBar","CloudburstTimer",CloudburstAbsorbBar);
CloudburstAbsorbBar.Timer:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar");
CloudburstAbsorbBar.Timer:GetStatusBarTexture():SetHorizTile(false);
CloudburstAbsorbBar.Timer:GetStatusBarTexture():SetVertTile(false);
CloudburstAbsorbBar.Timer:SetWidth(CloudburstAbsorbBar:GetWidth());
CloudburstAbsorbBar.Timer:SetHeight(CloudburstAbsorbBar:GetHeight());
CloudburstAbsorbBar.Timer:SetFrameStrata("MEDIUM");
CloudburstAbsorbBar.Timer:SetPoint("CENTER",CloudburstAbsorbBar,"CENTER",0,0);
CloudburstAbsorbBar.Timer:SetStatusBarColor(1,1,1,0.35);
CloudburstAbsorbBar.Timer:Hide();

CloudburstAbsorbBar.Timer.text = CloudburstAbsorbBar.Timer:CreateFontString(nil, "HIGH", "GameFontHighlightLarge");
CloudburstAbsorbBar.Timer.text:SetPoint("CENTER",CloudburstAbsorbBar.Timer,"LEFT",25,0);
CloudburstAbsorbBar.Timer.text:SetFont("Interface\\addons\\ShamanAuras\\Media\\fonts\\Continuum_Medium.ttf", 12);
CloudburstAbsorbBar.Timer.text:SetTextColor(1,1,1,1);]]
--[[local BackdropCB = {
	bgFile    = "Interface\\AddOns\\rSetBackdrop\\tga\\background_flat",
	edgeFile  = "Interface\\AddOns\\rSetBackdrop\\tga\\UI-Tooltip-Border",
	tile      = false,
	tileSize  = 16, 
	edgeSize  = 16, 
	insets     = {
		left = 4,
		right = 4,
		top = 4,
		bottom = 4,
	},
};]]
local BackdropCB = SSA.BackdropCB;
local BackdropCBInner = {
	bgFile    = "Interface\\AddOns\\ShamanAuras\\media\\icons\\totems\\cloudburst_totem", 
	edgeFile  = "Interface\\AddOns\\ShamanAuras\\media\\textures\\tooltip_border",
	tile      = false,
	tileSize  = 16, 
	edgeSize  = 16,
}
--[[SSA.Cloudburst = CreateFrame("Frame","Cloudburst",AuraGroup);
_G["SSA_Cloudburst"] = SSA.Cloudburst;
local Cloudburst = SSA.Cloudburst;]]
local Cloudburst = CreateFrame("Frame","Cloudburst",AuraGroup);
Cloudburst:SetFrameLevel(1);
--Cloudburst:SetWidth(150);
--Cloudburst:SetHeight(32);
Cloudburst:SetPoint("CENTER",AuraGroup,"CENTER",-200,0);
Cloudburst:SetBackdrop(BackdropCB);
Cloudburst:SetBackdropColor(0.15,0.15,0.15,0.6);
Cloudburst:SetBackdropBorderColor(1,1,1,1);
Cloudburst:SetAlpha(0);
Cloudburst:Show();

Cloudburst.text = Cloudburst:CreateFontString(nil, "MEDIUM", "GameFontHighlightLarge");
Cloudburst.text:SetPoint("RIGHT",Cloudburst,"RIGHT",-5,-1);
--Cloudburst.text:SetPoint("CENTER",0,0);
Cloudburst.text:SetTextColor(0,1,0,1);
Cloudburst.text:SetFont("Fonts\\FRIZQT__.TTF",22,"OUTLINE");
Cloudburst.text:SetJustifyH("LEFT");
Cloudburst.text:SetText('0');
--[[Cloudburst.inner = CreateFrame("Frame",nil,Cloudburst);
Cloudburst.inner:SetPoint("TOPLEFT",Cloudburst,"TOPLEFT",8,-8);
Cloudburst.inner:SetPoint("BOTTOMRIGHT",Cloudburst,"BOTTOMRIGHT",-8,8);
Cloudburst.inner:SetBackdrop(BackdropCBInner);
Cloudburst.inner:SetBackdropColor(0.15,0.8,1,0);
Cloudburst.inner:SetBackdropBorderColor(1,1,1,1);]]

Cloudburst.icon = CreateFrame("Frame",nil,Cloudburst);
Cloudburst:SetFrameLevel(2);
Cloudburst.icon:SetWidth(40);
Cloudburst.icon:SetHeight(40);
Cloudburst.icon:SetPoint("LEFT",Cloudburst,"LEFT",0,0);
Cloudburst.icon:SetBackdrop(BackdropCB);
Cloudburst.icon:SetBackdropColor(1,1,1,0);
Cloudburst.icon:SetBackdropBorderColor(1,1,1,1);

Cloudburst.icon.texture = Cloudburst.icon:CreateTexture(nil,"BACKGROUND");
Cloudburst.icon.texture:SetTexture("Interface\\addons\\ShamanAuras\\Media\\icons\\totems\\cloudburst_totem_bevel");
Cloudburst.icon.texture:SetAllPoints(Cloudburst.icon);
_G["SSA_Cloudburst"] = Cloudburst;
SSA.Cloudburst = Cloudburst;
--[[Cloudburst.icon.inner = CreateFrame("Frame",nil,Cloudburst);
Cloudburst.icon.inner:SetPoint("TOPLEFT",Cloudburst,"TOPLEFT",8,-8);
Cloudburst.icon.inner:SetPoint("BOTTOMRIGHT",Cloudburst,"BOTTOMRIGHT",-8,8);
Cloudburst.icon.inner:SetBackdrop(BackdropCBInner);
Cloudburst.icon.inner:SetBackdropColor(0.15,0.8,1,0);
Cloudburst.icon.inner:SetBackdropBorderColor(1,1,1,1);]]

-- Build Earthen Shield Status Bar
--SSA.EarthenShieldTotemBar = CreateFrame("StatusBar","EarthenShieldTotemBar",AuraGroup);
--local EarthenShieldTotemBar = SSA.EarthenShieldTotemBar;
local EarthenShieldTotemBar = CreateFrame("StatusBar","EarthenShieldTotemBar",AuraGroup);
_G["SSA_EarthenShield"] = EarthenShieldTotemBar;
EarthenShieldTotemBar:SetStatusBarTexture("Interface\\addons\\ShamanAuras\\media\\statusbar\\fifths");
EarthenShieldTotemBar:GetStatusBarTexture():SetHorizTile(false);
EarthenShieldTotemBar:GetStatusBarTexture():SetVertTile(false);
EarthenShieldTotemBar:SetPoint("CENTER",AuraGroup,"CENTER",0,-139);
--EarthenShieldTotemBar:SetWidth(260);
--EarthenShieldTotemBar:SetHeight(18);
EarthenShieldTotemBar:SetFrameStrata("LOW");
EarthenShieldTotemBar:SetStatusBarColor(0.91,0.41,1);
EarthenShieldTotemBar:Hide();

EarthenShieldTotemBar.bg = EarthenShieldTotemBar:CreateTexture(nil,"BACKGROUND");
EarthenShieldTotemBar.bg:SetTexture("Interface\\TargetingFrame\\UI-StatusBar");
EarthenShieldTotemBar.bg:SetAllPoints(true);
EarthenShieldTotemBar.bg:SetVertexColor(0,0,0);
EarthenShieldTotemBar.bg:SetAlpha(0.5);

EarthenShieldTotemBar.text = EarthenShieldTotemBar:CreateFontString(nil, "HIGH", "GameFontHighlightLarge");
EarthenShieldTotemBar.text:SetPoint("CENTER",EarthenShieldTotemBar,"RIGHT",-25,0);
EarthenShieldTotemBar.text:SetFont("Interface\\addons\\ShamanAuras\\Media\\fonts\\Continuum_Medium.ttf", 12);
EarthenShieldTotemBar.text:SetTextColor(1,1,1,1);

-- Build Earthen Shield Timer Status Bar
EarthenShieldTotemBar.Timer = CreateFrame("StatusBar","EarthenShieldTimer",EarthenShieldTotemBar);
EarthenShieldTotemBar.Timer:SetStatusBarTexture("Interface\\TargetingFrame\\UI-StatusBar");
EarthenShieldTotemBar.Timer:GetStatusBarTexture():SetHorizTile(false);
EarthenShieldTotemBar.Timer:GetStatusBarTexture():SetVertTile(false);
EarthenShieldTotemBar.Timer:SetWidth(EarthenShieldTotemBar:GetWidth());
EarthenShieldTotemBar.Timer:SetHeight(EarthenShieldTotemBar:GetHeight());
EarthenShieldTotemBar.Timer:SetFrameStrata("MEDIUM");
EarthenShieldTotemBar.Timer:SetPoint("CENTER",EarthenShieldTotemBar,"CENTER",0,0);
EarthenShieldTotemBar.Timer:SetStatusBarColor(1,1,1,0.35);
EarthenShieldTotemBar.Timer:Hide();

EarthenShieldTotemBar.Timer.text = EarthenShieldTotemBar.Timer:CreateFontString(nil, "HIGH", "GameFontHighlightLarge");
EarthenShieldTotemBar.Timer.text:SetPoint("CENTER",EarthenShieldTotemBar.Timer,"LEFT",25,0);
EarthenShieldTotemBar.Timer.text:SetFont("Interface\\addons\\ShamanAuras\\Media\\fonts\\Continuum_Medium.ttf", 12);
EarthenShieldTotemBar.Timer.text:SetTextColor(1,1,1,1);
SSA.EarthenShieldTotemBar = EarthenShieldTotemBar;

-- Build Buff Timer Status Bar Group
SSA.BuffTimerBarGrpRes = CreateFrame("Frame","BuffTimerBarGrpRes",AuraGroup);
local BuffTimerBarGrp = SSA.BuffTimerBarGrpRes;
BuffTimerBarGrp:SetWidth(131);
BuffTimerBarGrp:SetHeight(180);
BuffTimerBarGrp:SetBackdrop(nil);
BuffTimerBarGrp:Show();

-- Build Main Timer Status Bar Group
SSA.MainTimerBarGrpRes = CreateFrame("Frame","MainTimerBarGrpRes",AuraGroup);
local MainTimerBarGrp = SSA.MainTimerBarGrpRes;
MainTimerBarGrp:SetWidth(105);
MainTimerBarGrp:SetHeight(180);
MainTimerBarGrp:SetBackdrop(nil);
MainTimerBarGrp:Show();

-- Build Utility Timer Status Bar Group
SSA.UtilTimerBarGrpRes = CreateFrame("Frame","UtilTimerBarGrpRes",AuraGroup);
local UtilTimerBarGrp = SSA.UtilTimerBarGrpRes;
UtilTimerBarGrp:SetWidth(47);
UtilTimerBarGrp:SetHeight(180);
UtilTimerBarGrp:SetBackdrop(nil);
UtilTimerBarGrp:Show();

-- Build Restoration Vertical Status Bars
SSA.AncestralGuidanceBarRes = CreateFrame("StatusBar","AncestralGuidanceBarRes",BuffTimerBarGrp);
SSA.AncestralProtectionTotemBar = CreateFrame("StatusBar","AncestralProtectionTotemBar",MainTimerBarGrp);
SSA.AscendanceBarRes = CreateFrame("StatusBar","AscendanceBarRes",BuffTimerBarGrp);
SSA.AstralShiftBarRes = CreateFrame("StatusBar","AstralShiftBarRes",BuffTimerBarGrp);
SSA.BloodlustBarRes = CreateFrame("StatusBar","BloodlustBarRes",BuffTimerBarGrp);
SSA.CloudburstTotemBar = CreateFrame("StatusBar","CloudburstTotemBar",MainTimerBarGrp);
SSA.EarthgrabTotemBarRes = CreateFrame("StatusBar","EarthgrabTotemBarRes",UtilTimerBarGrp);
SSA.HealingStreamTotemBarOne = CreateFrame("StatusBar","HealingStreamTotemBarOne",MainTimerBarGrp);
SSA.HealingStreamTotemBarTwo = CreateFrame("StatusBar","HealingStreamTotemBarTwo",MainTimerBarGrp);
SSA.HealingTideTotemBar = CreateFrame("StatusBar","HealingTideTotemBar",MainTimerBarGrp);
SSA.HeroismBarRes = CreateFrame("StatusBar","HeroismBarRes",BuffTimerBarGrp);
SSA.HexBarRes = CreateFrame("StatusBar","HexBarRes",UtilTimerBarGrp);
SSA.SpiritLinkTotemBar = CreateFrame("StatusBar","SpiritLinkTotemBar",MainTimerBarGrp);
SSA.SpiritwalkersGraceBar = CreateFrame("StatusBar","SpiritwalkersGraceBar",BuffTimerBarGrp);
SSA.TimeWarpBarRes = CreateFrame("StatusBar","TimeWarpBarRes",BuffTimerBarGrp);
SSA.UnleashLifeBar = CreateFrame("StatusBar","UnleashLifeBar",BuffTimerBarGrp);
SSA.VoodooTotemBarRes = CreateFrame("StatusBar","VoodooTotemBarRes",UtilTimerBarGrp);
SSA.WindRushTotemBarRes = CreateFrame("StatusBar","WindRushTotemBarRes",UtilTimerBarGrp);


--[[-- Undulation Notification
SSA.Undulation = CreateFrame("Frame","Undulation",AuraGroup);
local Undulation = SSA.Undulation;
Undulation:SetPoint("CENTER",0,-210);
Undulation:SetWidth(400);
Undulation:SetHeight(180);
Undulation:SetFrameStrata("BACKGROUND");
Undulation:Hide();

Undulation.texture = Undulation:CreateTexture(nil,"LOW");
Undulation.texture:SetTexture("Textures\\SpellActivationOverlays\\Monk_Serpent");
Undulation.texture:SetPoint("CENTER",Undulation,"CENTER",0,0);
Undulation.texture:SetWidth(Undulation:GetWidth() + 20);
Undulation.texture:SetHeight(Undulation:GetHeight());
Undulation.texture:SetRotation(math.rad(-90));
Undulation.texture:SetAlpha(0.7);

-- Animation for Totem Mastery Notification Texture
Undulation.Flash = Undulation.texture:CreateAnimationGroup();
Undulation.Flash:SetLooping("BOUNCE");

Undulation.Flash.fadeIn = Undulation.Flash:CreateAnimation("Alpha");
Undulation.Flash.fadeIn:SetFromAlpha(1);
Undulation.Flash.fadeIn:SetToAlpha(0.4);
Undulation.Flash.fadeIn:SetDuration(0.4);

Undulation.Flash.fadeOut = Undulation.Flash:CreateAnimation("Alpha");
Undulation.Flash.fadeOut:SetFromAlpha(0.4);
Undulation.Flash.fadeOut:SetToAlpha(1);
Undulation.Flash.fadeOut:SetDuration(0.4);
Undulation.Flash.fadeOut:SetEndDelay(0);]]

--SSA.ErrorFrame.text:SetText("Name: "..StormkeeperCharges:GetName())
SSA.Undulation = CreateFrame("Frame","Undulation",AuraGroup);
local Undulation = SSA.Undulation;
--local StormkeeperCharge1 = SSA.StormkeeperCharge1;
Undulation:SetWidth(60);
Undulation:SetHeight(60);
Undulation:SetPoint("CENTER",AuraGroup,"CENTER",0,-275);
Undulation:SetAlpha(0);
Undulation:Show();

Undulation.Orb = CreateFrame("PlayerModel","StormkeeperCharge1_Orb",Undulation);
Undulation.Orb:SetModel("SPELLS/Monk_ForceSpere_Orb.m2");
Undulation.Orb:SetFrameStrata(low);
Undulation.Orb:SetPosition(0,0,0);
Undulation.Orb:SetAllPoints(Undulation);
Undulation.Orb:SetAlpha(1);
local elapsed = 0;
Undulation.Orb:HookScript("OnUpdate", function(self, elaps)
	elapsed = elapsed + (elaps * 1000);
	self:SetSequenceTime(1, elapsed);
end);

-- Lava Surge Progress Bar/Texture (LEFT)
--[[SSA.LavaSurgeRes = CreateFrame("StatusBar","LavaSurgeRes",AuraGroup);
local LavaSurge = SSA.LavaSurgeRes;

LavaSurge:SetStatusBarTexture("Textures\\SpellActivationOverlays\\Imp_Empowerment");
LavaSurge:GetStatusBarTexture():SetHorizTile(false);
LavaSurge:GetStatusBarTexture():SetVertTile(false);
LavaSurge:SetOrientation("VERTICAL");
LavaSurge:SetPoint("CENTER",AuraGroup,"CENTER",-130,0);
LavaSurge:SetWidth(116);
LavaSurge:SetHeight(200);
LavaSurge:SetFrameStrata("LOW");
LavaSurge:SetStatusBarColor(1,1,1);

LavaSurge.bg = LavaSurge:CreateTexture(nil,"BACKGROUND");
LavaSurge.bg:SetTexture("Textures\\SpellActivationOverlays\\Imp_Empowerment");
LavaSurge.bg:SetAllPoints(true);
LavaSurge.bg:SetVertexColor(1,1,1);
LavaSurge.bg:SetAlpha(0.5);

LavaSurge.Scaler = LavaSurge:CreateAnimationGroup();
LavaSurge.Scaler:SetLooping("REPEAT");

local scalePush = 1.08;
local scalePull = 1 / scalePush;

local scaleOut = LavaSurge.Scaler:CreateAnimation("Scale")
scaleOut:SetOrder(1)
scaleOut:SetDuration(0.5)
scaleOut:SetSmoothing("IN_OUT")
scaleOut:SetFromScale(1,1)
scaleOut:SetToScale(1,scalePush)
 
local scaleIn = LavaSurge.Scaler:CreateAnimation("Scale")
scaleIn:SetOrder(2)
scaleIn:SetDuration(0.5)
scaleIn:SetSmoothing("IN_OUT")
scaleIn:SetFromScale(1,1)
scaleIn:SetToScale(1,scalePull)
LavaSurge:Hide();]]

-------------------------------------------------------------------------------------------------------
----- Build Move UI
-------------------------------------------------------------------------------------------------------

SSA.MoveRes = CreateFrame("Frame","MoveRes",UIParent);

SSA.AuraObjectsRes = {
	[1] = {
		alpha = nil,
		object = AuraGroup,
		backdrop = "BackdropSB",
	},
	[2] = {
		alpha = nil,
		object = LargeIconGrpTop,
		backdrop = "BackdropSB",
	},
	[3] = {
		alpha = nil,
		object = LargeIconGrpBot,
		backdrop = "BackdropSB",
	},
	[4] = {
		alpha = nil,
		object = SmallIconGrpLeft,
		backdrop = "BackdropSB",
	},
	[5] = {
		alpha = nil,
		object = SmallIconGrpRight,
		backdrop = "BackdropSB",
	},
	[6] = {
		alpha = nil,
		object = BuffTimerBarGrp,
		backdrop = "BackdropSB",
	},
	[7] = {
		alpha = nil,
		object = MainTimerBarGrp,
		backdrop = "BackdropSB",
	},
	[8] = {
		alpha = nil,
		object = UtilTimerBarGrp,
		backdrop = "BackdropSB",
	},
	[9] = {
		alpha = false,
		object = EarthenShieldTotemBar,
		statusbar = {
			r = 0.91,
			g = 0.41,
			b = 1,
			m = 'player',
		},
	},
	[10] = {
		alpha = false,
		object = TidalWavesBar,
		statusbar = {
			r = 0.35,
			g = 0.76,
			b = 1,
			m = 2,
		},
	},
	--[11] = LavaSurge,
	[11] = {
		alpha = true,
		model = {
			[1] = Undulation.Orb,
		},
		object = Undulation,
		backdrop = 'BackdropSB',
	},
	[12] = {
		object = Cloudburst,
		alpha = true,
	},
	--[[[11] = CloudburstAbsorbBar,
	[12] = LavaSurge,]]
}

SSA.MoveStringsRes = {
	[1] = L["Move All Auras"],
	[2] = L["Move Top Auras"],
	[3] = L["Move Bottom Auras"],
	[4] = L["Move Left Auras"],
	[5] = L["Move Right Auras"],
	[6] = L["Move Buff Timer Bars"],
	[7] = L["Move Main Timer Bars"],
	[8] = L["Move Utility Timer Bars"],
	[9] = L["Move Earthen Shield Bar"],
	[10] = L["Move Tidal Waves Bar"],
	--[11] = L["Move Lava Surge Texture"],
	[11] = L["Move Undulation"],
	[12] = L["Cloudburst Healing Stored"],
	--[12] = L["Move Lava Surge Texture"],
}